--
-- Lights
--
-- @author  Jack
-- @date  30/04/09
--
-- Copyright (C) Jack

lichtscript1 = {};

function lichtscript1.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Steerable, specializations);
end;

function lichtscript1:load(xmlFile)

-- Rundumlicht
    self.rundumleuchtenAnz = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.rundumleuchten#count"),0);
    self.rundumleuchtenAn = false;
    self.rundumleuchten = {};
    for i=1, self.rundumleuchtenAnz do
        local objname = string.format("vehicle.rundumleuchten.light" .. "%d",i);
        self.rundumleuchten[i] = {};
        self.rundumleuchten[i].rotNode = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, objname .. "#rotNode"));
        self.rundumleuchten[i].light = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, objname .. "#light"));
        self.rundumleuchten[i].source = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, objname .. "#lightsource"));
        self.rundumleuchten[i].speed = Utils.getNoNil(getXMLInt(xmlFile,  objname .. "#rotSpeed"), 1)/1000;
        self.rundumleuchten[i].emit = Utils.getNoNil(getXMLBool(xmlFile, objname .. "#emitLight"), true);
        if not self.rundumleuchten[i].emit and self.rundumleuchten[i].source ~= nil then
           setVisibility(self.rundumleuchten[i].source, false);
        end;
    end;

    self.worklightfront = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.extra_lights.worklightfront#index"));
    self.worklightback = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.extra_lights.worklightback#index"));

-- Keys
    self.keys = {};
    local i=0;
    while true do
        local baseName = string.format("vehicle.keys.input(%d)", i);
        local inputName = getXMLString(xmlFile, baseName.. "#name");
        if inputName == nil then
            break;
        end;
        local inputKey = getXMLString(xmlFile, baseName.. "#key");
        if Input[inputKey] == nil then
            print("Error: invalid key '" .. inputKey .. "'  for input event '" .. inputName .. "'");
            break;
        end;
        self.keys[inputName] = Input[inputKey];
        i = i+1;
    end;

    self.showhelp = false;
    self.hudInfo = Utils.getFilename("hud_help_base.png", self.baseDirectory);
    self.hudInfoPoxX = 0.012;
    self.hudInfoPoxY = 0.1825;
    self.hudInfoWidth = 0.425;
    self.hudInfoHeight = 0.1625;
    self.hudInfoOverlay = Overlay:new("hudInfoOverlay", self.hudInfo, self.hudInfoPoxX, self.hudInfoPoxY, self.hudInfoWidth, self.hudInfoHeight);

self.worklightsFrontActive = false;
self.worklightsBackActive = false;

end;

function lichtscript1:keyEvent(unicode, sym, modifier, isDown)

    if isDown and sym == self.keys.rundumleuchte then
      self.rundumleuchtenAn = not self.rundumleuchtenAn;
      for i=1, self.rundumleuchtenAnz do
        setVisibility(self.rundumleuchten[i].light, self.rundumleuchtenAn);
      end;	
    end;
        
    if isDown and sym == self.keys.hilfe then
      if self.hudInfoOverlay ~= nil then
      	self.showhelp = not self.showhelp;
      end;
    end;

	if isDown and sym == self.keys.worklightfront then
		self.worklightsFrontActive = not self.worklightsFrontActive;
	end;

	if isDown and sym == self.keys.worklightback then
		self.worklightsBackActive = not self.worklightsBackActive;
	end;
end;

function lichtscript1:update(dt)

if self.isEntered then

	-- WorklightBack
		if self.worklightsBackActive then
				setVisibility(self.worklightback, self.worklightsBackActive);
		else
				setVisibility(self.worklightback, self.worklightsBackActive, false);
		end;

	-- WorklightFront
		if self.worklightsFrontActive then
				setVisibility(self.worklightfront, self.worklightsFrontActive);
		else
				setVisibility(self.worklightfront, self.worklightsFrontActive, false);
		end;

	-- Rundumlicht
        if self.rundumleuchtenAn then
          for i=1, self.rundumleuchtenAnz do
            rotate(self.rundumleuchten[i].rotNode, 0, dt*self.rundumleuchten[i].speed, 0);
          end;
		setVisibility(self.lightsrundum, self.rundumleuchtenAn);
	else
	setVisibility(self.lightsrundum, self.rundumleuchtenAn, false);
        end;

end;

end;

function lichtscript1:draw()

	setTextBold(true);

    if not self.showhelp then
	renderText(self.hudBasePoxX, self.hudBasePoxY+0.14, 0.021, string.format("%s%s%s" , "Taste:",""..key_convert(self.keys.hilfe).."" , "Hilfebox"));
    else
    	self.hudInfoOverlay:render();
    	local helptext={};
    	helptext[1] = "Taste "..key_convert(self.keys.rundumleuchte)..": Rundumleuchte";
    	helptext[2] = "Taste "..key_convert(self.keys.worklightback)..": Arbeitslicht Hinten";
    	helptext[3] = "Taste "..key_convert(self.keys.worklightfront)..": Arbeitslicht Vorne";
    	helptext[4] = string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.WINDOW), g_i18n:getText("Window"));
    	helptext[5] = string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.DOOR_Left), g_i18n:getText("DoorLeft"));
    	helptext[6] = string.format("Taste %s: %s", InputBinding.getButtonKeyName(InputBinding.DOOR_Right), g_i18n:getText("DoorRight"));
    	helptext[7] = "Taste "..key_convert(self.keys.hilfe)..": Hilfebox ausblenden";

    	if self.rundumleuchtenAn then
    		 helptext[1] = helptext[1].." (an)";
    	else
    		 helptext[1] = helptext[1].." (aus)";
    	end;
    	if self.worklightsBackActive then
    		 helptext[2] = helptext[2].." (an)";
    	else
    		 helptext[2] = helptext[2].." (aus)";
    	end;
    	if self.worklightsFrontActive then
    		 helptext[3] = helptext[3].." (an)";
    	else
    		 helptext[3] = helptext[3].." (aus)";
    	end;

		if self.rotationMaxwindow then
			 helptext[4] = helptext[4].." (auf)";
		else
			 helptext[4] = helptext[4].." (zu)";
		end;
		
		if self.DOORLeftMax then
			 helptext[5] = helptext[5].." (auf)";
		else
			 helptext[5] = helptext[5].." (zu)";
		end;

		if self.DOORRightMax then
			 helptext[6] = helptext[6].." (auf)";
		else
			 helptext[6] = helptext[6].." (zu)";
		end;

    	for i=1, table.getn(helptext) do
    		renderText((self.hudInfoPoxX+0.05),((self.hudInfoPoxY+self.hudInfoHeight) - (0.02*i)),0.02,helptext[i]);
    	end;
    end;

end;

function lichtscript1:onEnter()
end;

function lichtscript1:onLeave()

    	self.worklightsBackActive = false;
	self.worklightsFrontActive = false;
       setVisibility(self.worklightback, false);
       setVisibility(self.worklightfront, false);
       setVisibility(self.lightsrundum, false);

    self.rundumleuchtenAn = false;
    for i=1, self.rundumleuchtenAnz do
       setVisibility(self.rundumleuchten[i].light, self.rundumleuchtenAn);
    end;
end;

function lichtscript1:delete()

    	self.worklightsBackActive = false;
	self.worklightsFrontActive = false;
       setVisibility(self.worklightback, false);
       setVisibility(self.worklightfront, false);
       setVisibility(self.lightsrundum, false);

    self.rundumleuchtenAn = false;
    for i=1, self.rundumleuchtenAnz do
       setVisibility(self.rundumleuchten[i].light, self.rundumleuchtenAn);
    end;
end;

function lichtscript1:mouseEvent(posX, posY, isDown, isUp, button)
end;

function key_convert(key)
	if key < 256 then
		return string.upper(""..string.char(key).."");
	elseif key > 255 and key < 266 then
		return string.upper("KP"..string.char(key-208));
	else
		return "n/a";
	end;
end;






